==========
fintoolbox
==========


.. image:: https://img.shields.io/pypi/v/fintoolbox.svg
        :target: https://pypi.python.org/pypi/fintoolbox

.. image:: https://img.shields.io/travis/rgno1/fintoolbox.svg
        :target: https://travis-ci.com/rgno1/fintoolbox

.. image:: https://readthedocs.org/projects/fintoolbox/badge/?version=latest
        :target: https://fintoolbox.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Fintoolbox contains all the tools need to construct and manage financial portfolios.


* Free software: MIT license
* Documentation: https://fintoolbox.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
